<?php

global $newuser_text;
$newuser_text = array (

'registernewuser'	=>	'Registreer nieuwe gebruiker',
'requiredfields'	=>	'Vereiste velden zijn gemarkeerd met een a',
'username'			=>	'Gebruikersnaam',
'password'			=>	'Wachtwoord',
'confirmpass'		=>	'Bevestig wachtwoord',
'realname'			=>	'Echte naam',
'emailaddress'		=>	'Email Adres',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Berichten',
'none'				=>	'Geen',
'email'				=>	'Email',
'jabber'			=>	'Jabber',
//'group'				=>	'Groep',    Not used from 0.9.7
'registeraccount'	=>	'Registreer deze account',

// New in 0.9.7

'globalgroup'		=>	'Globale groep',

);
?>
